@@ -225,6 +225,19 @@ class Membership(models.Model):
         return f"{self.user} in {self.organization}"
 
 
+class Plan(models.Model):
+    """Plans that organizations can subscribe to
+    DEPRECATED: not removed as it breaks migrations
+    """
+
+    name = models.CharField(_("name"), max_length=255, unique=True)
+    slug = models.SlugField(_("slug"), max_length=255, unique=True)
+    resources = JSONField(default=dict)
+
+    def __str__(self):
+        return self.name
+
+
 class Entitlement(models.Model):
     """Entitlements granted to organizations through plans"""
 
